@@ -42,8 +42,7 @@ from plenum.common.constants import REPLY, POOL_LEDGER_TXNS, \
     MULTI_SIGNATURE_SIGNATURE, MULTI_SIGNATURE_VALUE
 from plenum.common.txn_util import idr_from_req_data
 from plenum.common.types import f
-from plenum.common.util import getMaxFailures, checkIfMoreThanFSameItems, \
-    rawToFriendly, mostCommonElement
+from plenum.common.util import getMaxFailures, rawToFriendly, mostCommonElement
 from plenum.persistence.client_req_rep_store_file import ClientReqRepStoreFile
 from plenum.persistence.client_txn_log import ClientTxnLog
 from plenum.server.has_action_queue import HasActionQueue
@@ -108,7 +107,6 @@ class Client(Motor,
         self.keys_dir = os.path.join(_keys_dir, "keys")
 
         cha = None
-        # If client information already exists is RAET then use that
         if self.exists(self.stackName, self.keys_dir):
             cha = self.nodeStackClass.getHaFromLocal(
                 self.stackName, self.keys_dir)
@@ -275,7 +273,7 @@ class Client(Motor,
             self.nodestack.start()
             self.nodestack.maintainConnections(force=True)
             if self.ledger:
-                self.ledgerManager.setLedgerCanSync(0, True)
+                self.ledgerManager.setLedgerCanSync(POOL_LEDGER_ID, True)
                 self.mode = Mode.starting
 
     async def prod(self, limit) -> int:
