@@ -29,7 +29,8 @@ def init_bls_keys(keys_dir, node_name, seed=None):
     return stored_pk
 
 
-def initNodeKeysForBothStacks(name, keys_dir, sigseed, *, use_bls=True, override=False):
+def initNodeKeysForBothStacks(name, keys_dir, sigseed, *, use_bls=True,
+                              override=False):
     # `sigseed` is initialised to keep the seed same for both stacks.
     # Both node and client stacks need to have same keys
     if not sigseed:
@@ -40,7 +41,9 @@ def initNodeKeysForBothStacks(name, keys_dir, sigseed, *, use_bls=True, override
 
     node_stack_name = name
     client_stack_name = node_stack_name + CLIENT_STACK_SUFFIX
+    print("Init local keys for client-stack")
     initLocalKeys(client_stack_name, keys_dir, sigseed, use_bls=False, override=override)
+    print("Init local keys for node-stack")
     keys = initLocalKeys(node_stack_name, keys_dir, sigseed, use_bls=use_bls, override=override)
     return keys
 
