@@ -72,6 +72,8 @@ reqIdToTxnStorage = KeyValueStorageType.Leveldb
 
 stateSignatureStorage = KeyValueStorageType.Leveldb
 
+transactionLogDefaultStorage = KeyValueStorageType.Leveldb
+
 DefaultPluginPath = {
     # PLUGIN_BASE_DIR_PATH: "<abs path of plugin directory can be given here,
     #  if not given, by default it will pickup plenum/server/plugin path>",
@@ -147,10 +149,11 @@ CatchupTransactionsTimeout = 6
 
 
 # Log configuration
-logRotationWhen = 'D'
+logRotationWhen = 'W6'
 logRotationInterval = 1
-logRotationBackupCount = 10
+logRotationBackupCount = 50
 logRotationMaxBytes = 100 * 1024 * 1024
+logRotationCompress = True
 logFormat = '{asctime:s} | {levelname:8s} | {filename:20s} ({lineno: >4}) | {funcName:s} | {message:s}'
 logFormatStyle = '{'
 logLevel = logging.NOTSET
@@ -211,6 +214,7 @@ CLIENT_MAX_RETRY_ACK = 5
 CLIENT_MAX_RETRY_REPLY = 5
 
 VIEW_CHANGE_TIMEOUT = 60  # seconds
+INSTANCE_CHANGE_TIMEOUT = 60
 MAX_CATCHUPS_DONE_DURING_VIEW_CHANGE = 5
 MIN_TIMEOUT_CATCHUPS_DONE_DURING_VIEW_CHANGE = 15
 
