@@ -1,4 +1,5 @@
 import pytest
+from plenum.test.helper import sdk_send_random_request
 
 from stp_core.loop.eventually import eventually
 from plenum.common.messages.node_messages import Commit
@@ -27,9 +28,12 @@ def configNodeSet(txnPoolNodeSet):
     return txnPoolNodeSet
 
 
-def testMsgFromInstanceDelay(configNodeSet, looper, prepared1):
+def testMsgFromInstanceDelay(configNodeSet, looper,
+                             sdk_pool_handle, sdk_wallet_client):
     A, B, C, D = configNodeSet
 
+    sdk_send_random_request(looper, sdk_pool_handle, sdk_wallet_client)
+
     def getCommits(node: TestNode, instId: int):
         replica = node.replicas[instId]  # type: Replica
         return list(replica.commits.values())
