@@ -11,16 +11,15 @@ from plenum.test.malicious_behaviors_node import makeNodeFaulty, \
     sendDuplicate3PhaseMsg
 from plenum.test.test_node import getNonPrimaryReplicas, getPrimaryReplica
 from plenum.test import waits
-
-whitelist = [Suspicions.DUPLICATE_PR_SENT.reason,
-             'Invalid prepare message received',
-             'cannot process incoming PREPARE']
+from plenum.test.node_request.conftest import committed1, \
+    prepared1, preprepared1, propagated1, reqAcked1, \
+    sent1, noRetryReq, faultyNodes
 
 
 @pytest.fixture("module")
-def setup(nodeSet, up):
-    primaryRep, nonPrimaryReps = getPrimaryReplica(nodeSet, 0), \
-        getNonPrimaryReplicas(nodeSet, 0)
+def setup(txnPoolNodeSet):
+    primaryRep, nonPrimaryReps = getPrimaryReplica(txnPoolNodeSet, 0), \
+                                 getNonPrimaryReplicas(txnPoolNodeSet, 0)
 
     # A non primary replica sends duplicate PREPARE requests to all other
     # replicas
@@ -34,7 +33,7 @@ def setup(nodeSet, up):
     # want to check for a particular suspicion
 
     whitelistNode(faultyRep.node.name,
-                  [node for node in nodeSet if node != faultyRep.node],
+                  [node for node in txnPoolNodeSet if node != faultyRep.node],
                   Suspicions.DUPLICATE_PR_SENT.code)
 
     return adict(primaryRep=primaryRep, nonPrimaryReps=nonPrimaryReps,
@@ -50,7 +49,7 @@ def testMultiplePrepare(setup, looper, sent1):
     """
 
     primaryRep, nonPrimaryReps, faultyRep = setup.primaryRep, \
-        setup.nonPrimaryReps, setup.faultyRep
+                                            setup.nonPrimaryReps, setup.faultyRep
 
     def chkSusp():
         for r in (primaryRep, *nonPrimaryReps):
