@@ -1,12 +1,11 @@
 import pytest
+from plenum.test.node_request.helper import sdk_ensure_pool_functional
 
 from stp_core.loop.eventually import eventually
 from stp_core.common.log import getlogger
 from plenum.common.startable import Mode
 from plenum.test.delayers import cqDelay
-from plenum.test.helper import sendRandomRequests
-from plenum.test.node_catchup.helper import \
-    ensureClientConnectedToNodesAndPoolLedgerSame
+from plenum.test.helper import sdk_send_random_requests
 from plenum.test.test_node import checkNodesConnected
 from plenum.test import waits
 
@@ -16,19 +15,19 @@ txnCount = 10
 
 
 @pytest.fixture("module")
-def nodeStashingOrderedRequests(txnPoolNodeSet, nodeCreatedAfterSomeTxns):
-    looper, newNode, client, wallet, _, _ = nodeCreatedAfterSomeTxns
+def nodeStashingOrderedRequests(txnPoolNodeSet, sdk_node_created_after_some_txns):
+    looper, new_node, sdk_pool_handle, new_steward_wallet_handle = sdk_node_created_after_some_txns
     for node in txnPoolNodeSet:
         node.nodeIbStasher.delay(cqDelay(5))
-    txnPoolNodeSet.append(newNode)
-    ensureClientConnectedToNodesAndPoolLedgerSame(looper, client,
-                                                  *txnPoolNodeSet[:-1])
-    sendRandomRequests(wallet, client, 10)
+    txnPoolNodeSet.append(new_node)
+
+    sdk_ensure_pool_functional(looper, txnPoolNodeSet, new_steward_wallet_handle, sdk_pool_handle)
+    sdk_send_random_requests(looper, sdk_pool_handle, new_steward_wallet_handle, 10)
     looper.run(checkNodesConnected(txnPoolNodeSet))
 
     def stashing():
-        assert newNode.mode != Mode.participating
-        assert len(newNode.stashedOrderedReqs) > 0
+        assert new_node.mode != Mode.participating
+        assert len(new_node.stashedOrderedReqs) > 0
         # assert len(newNode.reqsFromCatchupReplies) > 0
 
     timeout = waits.expectedTransactionExecutionTime(len(txnPoolNodeSet))
