@@ -1,7 +1,12 @@
 import pytest
 import types
 
+from plenum.common.util import randomString
+from plenum.test.helper import sdk_send_random_and_check
+
 from plenum.common.ledger import Ledger
+from plenum.test.conftest import getValueFromModule
+from plenum.test.pool_transactions.helper import sdk_add_new_steward_and_node, sdk_pool_refresh
 from stp_core.common.log import getlogger
 from plenum.common.constants import TXN_TYPE, DOMAIN_LEDGER_ID
 from plenum.common.messages.node_messages import CatchupReq, CatchupRep
@@ -18,8 +23,11 @@ logger = getlogger()
 txnCount = 10
 
 
-def testNodeRejectingInvalidTxns(tconf, txnPoolNodeSet, patched_node,
-                                 nodeCreatedAfterSomeTxns):
+def testNodeRejectingInvalidTxns(looper, sdk_pool_handle, sdk_wallet_client,
+                                 tconf, tdir, txnPoolNodeSet, patched_node,
+                                 request,
+                                 sdk_wallet_steward, testNodeClass, allPluginsPath,
+                                 do_post_node_creation):
     """
     A newly joined node is catching up and sends catchup requests to other
     nodes but one of the nodes replies with incorrect transactions. The newly
@@ -27,7 +35,20 @@ def testNodeRejectingInvalidTxns(tconf, txnPoolNodeSet, patched_node,
     the node. Ii thus cannot complete the process till the timeout and then
     requests the missing transactions.
     """
-    looper, newNode, client, wallet, _, _ = nodeCreatedAfterSomeTxns
+    txnCount = getValueFromModule(request, "txnCount", 5)
+    sdk_send_random_and_check(looper, txnPoolNodeSet,
+                              sdk_pool_handle,
+                              sdk_wallet_client,
+                              txnCount)
+    new_steward_name = randomString()
+    new_node_name = "Epsilon"
+    new_steward_wallet_handle, new_node = sdk_add_new_steward_and_node(
+        looper, sdk_pool_handle, sdk_wallet_steward,
+        new_steward_name, new_node_name, tdir, tconf, nodeClass=testNodeClass,
+        allPluginsPath=allPluginsPath, autoStart=True,
+        do_post_node_creation=do_post_node_creation)
+    sdk_pool_refresh(looper, sdk_pool_handle)
+
     bad_node = patched_node
 
     do_not_tell_clients_about_newly_joined_node(txnPoolNodeSet)
@@ -42,10 +63,10 @@ def testNodeRejectingInvalidTxns(tconf, txnPoolNodeSet, patched_node,
 
     # have to skip seqno_db check because the txns are not executed
     # on the new node
-    waitNodeDataEquality(looper, newNode, *txnPoolNodeSet[:-1],
+    waitNodeDataEquality(looper, new_node, *txnPoolNodeSet[:-1],
                          customTimeout=timeout)
 
-    assert newNode.isNodeBlacklisted(bad_node.name)
+    assert new_node.isNodeBlacklisted(bad_node.name)
 
 
 @pytest.fixture
