@@ -5,7 +5,7 @@ import pytest
 from plenum.common.constants import DOMAIN_LEDGER_ID
 from stp_core.common.log import getlogger
 from plenum.common.messages.node_messages import CatchupReq
-from plenum.test.helper import sendRandomRequests
+from plenum.test.helper import sdk_send_random_requests
 from plenum.test.node_catchup.helper import waitNodeDataEquality
 from plenum.test.test_node import checkNodesConnected, getNonPrimaryReplicas
 from plenum.test import waits
@@ -31,15 +31,15 @@ def reduced_catchup_timeout_conf(tconf, request):
 
 
 def testNodeRequestingTxns(reduced_catchup_timeout_conf, txnPoolNodeSet,
-                           nodeCreatedAfterSomeTxns):
+                           sdk_node_created_after_some_txns, sdk_wallet_client):
     """
     A newly joined node is catching up and sends catchup requests to other
     nodes but one of the nodes does not reply and the newly joined node cannot
     complete the process till the timeout and then requests the missing
     transactions.
     """
-    looper, newNode, client, wallet, _, _ = nodeCreatedAfterSomeTxns
-    new_node_ledger = newNode.ledgerManager.ledgerRegistry[DOMAIN_LEDGER_ID]
+    looper, new_node, sdk_pool_handle, new_steward_wallet_handle = sdk_node_created_after_some_txns
+    new_node_ledger = new_node.ledgerManager.ledgerRegistry[DOMAIN_LEDGER_ID]
     old_size = len(new_node_ledger.ledger)
     old_size_others = txnPoolNodeSet[0].ledgerManager.ledgerRegistry[DOMAIN_LEDGER_ID].ledger.size
 
@@ -56,19 +56,19 @@ def testNodeRequestingTxns(reduced_catchup_timeout_conf, txnPoolNodeSet,
     npr = getNonPrimaryReplicas(txnPoolNodeSet, 0)
     badReplica = npr[0]
     badNode = badReplica.node
-    txnPoolNodeSet.append(newNode)
+    txnPoolNodeSet.append(new_node)
 
     badNode.nodeMsgRouter.routes[CatchupReq] = types.MethodType(
         ignoreCatchupReq, badNode.ledgerManager)
     more_requests = 10
-    sendRandomRequests(wallet, client, more_requests)
+    sdk_send_random_requests(looper, sdk_pool_handle, sdk_wallet_client, more_requests)
     looper.run(checkNodesConnected(txnPoolNodeSet))
 
     # Since one of the nodes does not reply, this new node will experience a
     # timeout and retry catchup requests, hence a long test timeout.
     timeout = waits.expectedPoolGetReadyTimeout(len(txnPoolNodeSet)) + \
               reduced_catchup_timeout_conf.CatchupTransactionsTimeout
-    waitNodeDataEquality(looper, newNode, *txnPoolNodeSet[:-1],
+    waitNodeDataEquality(looper, new_node, *txnPoolNodeSet[:-1],
                          customTimeout=timeout)
     new_size = len(new_node_ledger.ledger)
 
@@ -76,6 +76,6 @@ def testNodeRequestingTxns(reduced_catchup_timeout_conf, txnPoolNodeSet,
     # `more_request` transactions
     assert old_size_others - \
            old_size <= new_node_ledger.num_txns_caught_up <= new_size - old_size
-    sendRandomRequests(wallet, client, 2)
-    waitNodeDataEquality(looper, newNode, *txnPoolNodeSet[:-1],
+    sdk_send_random_requests(looper, sdk_pool_handle, sdk_wallet_client, 2)
+    waitNodeDataEquality(looper, new_node, *txnPoolNodeSet[:-1],
                          customTimeout=timeout)
