@@ -1,6 +1,7 @@
 from functools import partial
 
 import pytest
+
 from stp_core.common.util import adict
 
 from plenum.test.malicious_behaviors_node import makeNodeFaulty, \
@@ -12,10 +13,10 @@ whitelist = ['cannot process incoming PREPARE']
 
 
 @pytest.fixture(scope="module")
-def setup(startedNodes):
+def setup(txnPoolNodeSet):
     # Making nodes faulty such that no primary is chosen
-    A = startedNodes.Gamma
-    B = startedNodes.Zeta
+    A = txnPoolNodeSet[-2]
+    B = txnPoolNodeSet[-1]
     # Delay processing of PRE-PREPARE messages by Alpha and Beta for 90
     # seconds since the timeout for checking sufficient commits is 60 seconds
     makeNodeFaulty(A, partial(delaysPrePrepareProcessing, delay=90))
@@ -27,7 +28,7 @@ def setup(startedNodes):
 
 
 @pytest.fixture(scope="module")
-def afterElection(setup, up):
+def afterElection(setup):
     for n in setup.faulties:
         for r in n.replicas:
             assert not r.isPrimary
