@@ -2,10 +2,7 @@ import pytest
 from plenum.test.delayers import ppgDelay, req_delay
 from plenum.test.spy_helpers import get_count, getAllReturnVals
 from plenum.test.test_node import getNonPrimaryReplicas
-from plenum.test.helper import sdk_send_random_and_check, \
-    sdk_send_batches_of_random_and_check
-from plenum.test.node_request.helper import sdk_ensure_pool_functional
-from plenum.test.pool_transactions.conftest import looper
+from plenum.test.helper import sdk_send_random_and_check
 from plenum.test.node_request.helper import sdk_ensure_pool_functional
 
 
@@ -30,7 +27,7 @@ def setup(request, txnPoolNodeSet):
 
 
 def test_node_request_propagates(looper, setup, txnPoolNodeSet,
-                                 sdk_wallet_client, sdk_pool_handle, request):
+                                 sdk_wallet_client, sdk_pool_handle):
     """
     One of node lacks sufficient propagates
     """
@@ -41,6 +38,12 @@ def test_node_request_propagates(looper, setup, txnPoolNodeSet,
     old_count_request_propagates = get_count(
         faulty_node, faulty_node.request_propagates)
 
+    def sum_of_sent_batches():
+        return faulty_node.replicas[0].lastPrePrepareSeqNo + \
+               faulty_node.replicas[1].lastPrePrepareSeqNo
+
+    old_sum_of_sent_batches = sum_of_sent_batches()
+
     sent_reqs = 5
     sdk_send_random_and_check(looper,
                               txnPoolNodeSet,
@@ -57,10 +60,12 @@ def test_node_request_propagates(looper, setup, txnPoolNodeSet,
         assert get_count(
             faulty_node, faulty_node.processRequest) == old_count_recv_req
 
-    # Attempt to request PROPAGATEs was made twice, since the faulty node has
-    # 2 replicas
+    # Attempt to request PROPAGATEs was made as many number of times as the
+    # number of sent batches in both replicas since both replicas
+    # independently request PROPAGATEs
     assert get_count(faulty_node, faulty_node.request_propagates) - \
-        old_count_request_propagates == 2
+           old_count_request_propagates == (sum_of_sent_batches() -
+                                            old_sum_of_sent_batches)
 
     requested_propagate_counts = getAllReturnVals(
         faulty_node, faulty_node.request_propagates)
@@ -73,8 +78,7 @@ def test_node_request_propagates(looper, setup, txnPoolNodeSet,
 
     faulty_node.nodeIbStasher.reset_delays_and_process_delayeds()
     sdk_ensure_pool_functional(looper,
-                           txnPoolNodeSet,
-                           sdk_wallet_client,
-                           sdk_pool_handle,
-                           num_reqs=4)
-
+                               txnPoolNodeSet,
+                               sdk_wallet_client,
+                               sdk_pool_handle,
+                               num_reqs=4)
