@@ -18,19 +18,19 @@ Num of PROPAGATE messages must be less than sufficient (faultyNodes + 1)
 # behavior and should be chose randomly later.
 
 @pytest.fixture(scope="module")
-def setup(startedNodes):
-    E = startedNodes.Eta
-    Z = startedNodes.Gamma
-    Z = startedNodes.Zeta
-    for node in E, Z, Z:
+def setup(txnPoolNodeSet):
+    E = txnPoolNodeSet[-3]
+    G = txnPoolNodeSet[-2]
+    Z = txnPoolNodeSet[-1]
+    for node in E, G, Z:
         makeNodeFaulty(node, changesRequest)
         # Delaying nomination to avoid becoming primary
         # node.delaySelfNomination(10)
-    return adict(faulties=(E, Z, Z))
+    return adict(faulties=(E, G, Z))
 
 
 @pytest.fixture(scope="module")
-def afterElection(setup, up):
+def afterElection(setup):
     for n in setup.faulties:
         for r in n.replicas:
             assert not r.isPrimary
