@@ -5,6 +5,7 @@ from indy.ledger import build_node_request, build_nym_request, build_get_txn_req
 from indy.pool import refresh_pool_ledger
 from plenum.test.node_catchup.helper import waitNodeDataEquality, \
     ensureClientConnectedToNodesAndPoolLedgerSame
+from plenum.test.node_request.helper import sdk_ensure_pool_functional
 from stp_core.loop.looper import Looper
 from stp_core.types import HA
 from typing import Iterable, Union, Callable
@@ -447,6 +448,7 @@ def sdk_send_update_node(looper, sdk_submitter_wallet,
 
     # waitng for replies
     reply = sdk_get_and_check_replies(looper, [request_couple])[0][1]
+    sdk_pool_refresh(looper, sdk_pool_handle)
     return reply
 
 
@@ -503,7 +505,8 @@ def update_node_data_and_reconnect(looper, txnPoolNodeSet,
     txnPoolNodeSet[idx] = restartedNode
 
     looper.run(checkNodesConnected(txnPoolNodeSet))
-    sdk_pool_refresh(looper, sdk_pool_handle)
+    sdk_ensure_pool_functional(looper, txnPoolNodeSet,
+                               steward_wallet, sdk_pool_handle)
     return restartedNode
 
 
