@@ -5,7 +5,8 @@ from plenum.test.node_catchup.helper import waitNodeDataEquality
 from plenum.test.primary_selection.helper import check_newly_added_nodes, \
     getPrimaryNodesIdxs
 from plenum.test.pool_transactions.helper import buildPoolClientAndWallet
-from plenum.test.pool_transactions.conftest import nodeThetaAdded
+from plenum.test.pool_transactions.conftest import nodeThetaAdded, \
+    sdk_node_theta_added
 
 
 @pytest.fixture(scope="module")
