@@ -2,18 +2,35 @@ import os
 import logging
 import time
 import collections
+import gzip
+import pytest
 
 from stp_core.common.logging.TimeAndSizeRotatingFileHandler \
     import TimeAndSizeRotatingFileHandler
+from stp_core.common.log import Logger
 
 
-def test_time_log_rotation(tdir_for_func):
+@pytest.fixture(params=[False, True], ids=["plain", "compressed"])
+def log_compression(request):
+    return request.param
+
+def test_default_log_rotation_config_is_correct(tdir_for_func):
+    logDirPath = tdir_for_func
+    logFile = os.path.join(logDirPath, "log")
+    logger = Logger()
+
+    # Assert this doesn't fail
+    logger.enableFileLogging(logFile)
+
+
+def test_time_log_rotation(tdir_for_func, log_compression):
     logDirPath = tdir_for_func
     logFile = os.path.join(logDirPath, "log")
     logger = logging.getLogger('test_time_log_rotation-logger')
 
     logger.setLevel(logging.DEBUG)
-    handler = TimeAndSizeRotatingFileHandler(logFile, interval=1, when='s')
+    handler = TimeAndSizeRotatingFileHandler(
+        logFile, interval=1, when='s', compress=log_compression)
     logger.addHandler(handler)
     for i in range(3):
         time.sleep(1)
@@ -21,14 +38,14 @@ def test_time_log_rotation(tdir_for_func):
     assert len(os.listdir(logDirPath)) == 4  # initial + 3 new
 
 
-def test_size_log_rotation(tdir_for_func):
+def test_size_log_rotation(tdir_for_func, log_compression):
     logDirPath = tdir_for_func
     logFile = os.path.join(logDirPath, "log")
     logger = logging.getLogger('test_time_log_rotation-logger')
 
     logger.setLevel(logging.DEBUG)
     handler = TimeAndSizeRotatingFileHandler(
-        logFile, maxBytes=(4 + len(os.linesep)) * 4 + 1)
+        logFile, maxBytes=(4 + len(os.linesep)) * 4 + 1, compress=log_compression)
     logger.addHandler(handler)
     for i in range(20):
         logger.debug("line")
@@ -37,14 +54,14 @@ def test_size_log_rotation(tdir_for_func):
     assert len(os.listdir(logDirPath)) == 5
 
 
-def test_time_and_size_log_rotation(tdir_for_func):
+def test_time_and_size_log_rotation(tdir_for_func, log_compression):
     logDirPath = tdir_for_func
     logFile = os.path.join(logDirPath, "log")
     logger = logging.getLogger('test_time_and_size_log_rotation-logger')
 
     logger.setLevel(logging.DEBUG)
     handler = TimeAndSizeRotatingFileHandler(
-        logFile, maxBytes=(4 + len(os.linesep)) * 4 + 1, interval=1, when="s")
+        logFile, maxBytes=(4 + len(os.linesep)) * 4 + 1, interval=1, when="s", compress=log_compression)
     logger.addHandler(handler)
 
     for i in range(20):
@@ -57,7 +74,7 @@ def test_time_and_size_log_rotation(tdir_for_func):
     assert len(os.listdir(logDirPath)) == 8
 
 
-def test_time_and_size_log_rotation1(tdir_for_func):
+def test_time_and_size_log_rotation1(tdir_for_func, log_compression):
     log_dir_path = tdir_for_func
     logFile = os.path.join(log_dir_path, "log")
     logger = logging.getLogger('test_time_and_size_log_rotation-logger1')
@@ -73,7 +90,7 @@ def test_time_and_size_log_rotation1(tdir_for_func):
     handler = TimeAndSizeRotatingFileHandler(
         logFile,
         maxBytes=(record_length + len(os.linesep)) * record_per_file + 1,
-        interval=1, when="h", backupCount=backup_count, utc=True)
+        interval=1, when="h", backupCount=backup_count, utc=True, compress=log_compression)
     logger.addHandler(handler)
 
     for i in range(1, record_count + 1):
@@ -90,6 +107,7 @@ def test_time_and_size_log_rotation1(tdir_for_func):
     assert len(cir_buffer) == len(circ_buffer_set)
     assert len(os.listdir(log_dir_path)) == (backup_count + 1)
     for file_name in os.listdir(log_dir_path):
-        with open(os.path.join(log_dir_path, file_name)) as file:
+        open_fn = gzip.open if file_name.endswith(".gz") else open
+        with open_fn(os.path.join(log_dir_path, file_name), "rt") as file:
             for line in file.readlines():
                 assert line.strip() in circ_buffer_set
