@@ -12,8 +12,8 @@ from plenum.common.types import f
 from plenum.common.util import getTimeBasedId
 from plenum.server.validator_info_tool import ValidatorNodeInfoTool
 from plenum.test import waits
-from plenum.test.helper import waitForSufficientRepliesForRequests, \
-    sendRandomRequest, check_sufficient_replies_received
+from plenum.test.helper import check_sufficient_replies_received, \
+    sdk_send_random_and_check
 # noinspection PyUnresolvedReferences
 from plenum.test.node_catchup.helper import ensureClientConnectedToNodesAndPoolLedgerSame
 from plenum.test.pool_transactions.helper import disconnect_node_and_ensure_disconnected
@@ -246,14 +246,15 @@ def read_txn_and_get_latest_info(txnPoolNodesLooper, patched_dump_info_period,
 
 @pytest.fixture
 def write_txn_and_get_latest_info(txnPoolNodesLooper,
-                                  client_and_wallet,
+                                  sdk_pool_handle,
+                                  sdk_wallet_client,
                                   patched_dump_info_period,
                                   info_path):
-    client, wallet = client_and_wallet
-
     def write_wrapped():
-        req = sendRandomRequest(wallet, client)
-        waitForSufficientRepliesForRequests(txnPoolNodesLooper, client, requests=[req])
+        sdk_send_random_and_check(txnPoolNodesLooper, range(nodeCount),
+                                  sdk_pool_handle,
+                                  sdk_wallet_client,
+                                  1)
         txnPoolNodesLooper.runFor(patched_dump_info_period)
         return load_info(info_path)
 
