@@ -3,11 +3,9 @@ from itertools import combinations
 from stp_core.loop.eventually import eventually
 
 from plenum.test import waits
-from plenum.test.helper import sendRandomRequests, \
-    send_reqs_to_nodes_and_verify_all_replies, \
-    waitForSufficientRepliesForRequests, \
-    checkViewNoForNodes, \
-    check_last_ordered_3pc
+from plenum.test.helper import checkViewNoForNodes, \
+    check_last_ordered_3pc, sdk_send_random_request, sdk_get_replies, \
+    sdk_send_random_and_check
 from plenum.test.delayers import delay_3pc_messages, \
     reset_delays_and_process_delayeds
 from plenum.test.view_change.helper import ensure_view_change_complete
@@ -26,14 +24,14 @@ def check_nodes_requests_size(nodes, size):
 
 
 def test_view_change_gc_in_between_3pc_all_nodes_delays(
-        looper, txnPoolNodeSet, wallet1, client1):
+        looper, txnPoolNodeSet, sdk_pool_handle, sdk_wallet_client):
     """
     Test that garbage collector compares the whole 3PC key (viewNo, ppSeqNo)
     and does not remove messages from node's queues that have higher
     viewNo than last ordered one even if their ppSeqNo are less or equal
     """
 
-    numNodes = len(client1.nodeReg)
+    numNodes = len(txnPoolNodeSet)
     viewNo = checkViewNoForNodes(txnPoolNodeSet)
 
     # 1 send two messages one by one separately to make
@@ -43,8 +41,10 @@ def test_view_change_gc_in_between_3pc_all_nodes_delays(
     #       for master instances only cause non-master ones have
     #       specific logic of its management which we don't care in
     #       the test, see Replica::_setup_for_non_master)
-    send_reqs_to_nodes_and_verify_all_replies(looper, wallet1, client1, 1)
-    send_reqs_to_nodes_and_verify_all_replies(looper, wallet1, client1, 1)
+    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
+                              sdk_wallet_client, 1)
+    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
+                              sdk_wallet_client, 1)
 
     last_ordered_3pc = (viewNo, 2)
     check_nodes_last_ordered_3pc(txnPoolNodeSet, last_ordered_3pc)
@@ -72,7 +72,7 @@ def test_view_change_gc_in_between_3pc_all_nodes_delays(
     delay_3pc_messages(txnPoolNodeSet,
                        1,
                        delay=propagationTimeout * 2)
-    requests = sendRandomRequests(wallet1, client1, 1)
+    requests = sdk_send_random_request(looper, sdk_pool_handle, sdk_wallet_client)
 
     def checkPrePrepareSentAtLeastByPrimary():
         for node in txnPoolNodeSet:
@@ -102,8 +102,7 @@ def test_view_change_gc_in_between_3pc_all_nodes_delays(
     #    -> they should be ordered
     #    -> last_ordered_3pc = (+2, 1)
     reset_delays_and_process_delayeds(txnPoolNodeSet)
-    waitForSufficientRepliesForRequests(looper, client1,
-                                        requests=requests)
+    sdk_get_replies(looper, [requests])
 
     checkViewNoForNodes(txnPoolNodeSet, viewNo)
     last_ordered_3pc = (viewNo, 1)
