@@ -1,10 +1,9 @@
 import pytest
-import types
 
 from plenum.test.view_change.helper import ensure_all_nodes_have_same_data, \
-    ensure_view_change_by_primary_restart, start_stopped_node
+    ensure_view_change_by_primary_restart
 from plenum.common.constants import DOMAIN_LEDGER_ID, LedgerState, POOL_LEDGER_ID
-from plenum.test.helper import sendReqsToNodesAndVerifySuffReplies
+from plenum.test.helper import sdk_send_random_and_check
 
 from stp_core.common.log import getlogger
 from stp_core.loop.eventually import eventually
@@ -12,7 +11,7 @@ from plenum.test.node_catchup.helper import check_ledger_state, \
     waitNodeDataEquality
 from plenum.common.util import randomString
 from plenum.test.test_node import checkNodesConnected
-from plenum.test.pool_transactions.helper import addNewStewardAndNode
+from plenum.test.pool_transactions.helper import sdk_add_new_steward_and_node, sdk_pool_refresh
 from plenum.test import waits
 from plenum.common.startable import Mode
 
@@ -41,30 +40,27 @@ def catchuped(node):
     assert node.mode == Mode.participating
 
 
-def add_new_node(looper, nodes, steward, steward_wallet,
+def add_new_node(looper, nodes, sdk_pool_handle, sdk_wallet_steward,
                  tdir, client_tdir, tconf, all_plugins_path, name=None):
     node_name = name or "Psi"
     new_steward_name = "testClientSteward" + randomString(3)
-    new_steward, new_steward_wallet, new_node = addNewStewardAndNode(looper,
-                                                                     steward,
-                                                                     steward_wallet,
-                                                                     new_steward_name,
-                                                                     node_name,
-                                                                     tdir,
-                                                                     client_tdir,
-                                                                     tconf,
-                                                                     all_plugins_path)
+    _, new_node = sdk_add_new_steward_and_node(
+        looper, sdk_pool_handle, sdk_wallet_steward,
+        new_steward_name, node_name, tdir, tconf,
+        allPluginsPath=all_plugins_path)
     nodes.append(new_node)
     looper.run(checkNodesConnected(nodes))
     timeout = waits.expectedPoolCatchupTime(nodeCount=len(nodes))
     waitNodeDataEquality(looper, new_node, *nodes[:-1],
                          customTimeout=timeout)
+    sdk_pool_refresh(looper, sdk_pool_handle)
     return new_node
 
 
 def test_6th_node_join_after_view_change_by_master_restart(
         looper, txnPoolNodeSet, tdir, tconf,
-        allPluginsPath, steward1, stewardWallet,
+        allPluginsPath, sdk_pool_handle,
+        sdk_wallet_steward,
         client_tdir, limitTestRunningTime):
     """
     Test steps:
@@ -88,18 +84,20 @@ def test_6th_node_join_after_view_change_by_master_restart(
         for node in pool_of_nodes:
             looper.run(eventually(catchuped, node, timeout=2 * timeout))
     ensure_all_nodes_have_same_data(looper, pool_of_nodes, custom_timeout=timeout)
-    sendReqsToNodesAndVerifySuffReplies(looper, stewardWallet, steward1, 5)
+    sdk_send_random_and_check(looper, txnPoolNodeSet,
+                              sdk_pool_handle, sdk_wallet_steward, 5)
 
     new_epsilon_node = add_new_node(looper,
                                     pool_of_nodes,
-                                    steward1,
-                                    stewardWallet,
+                                    sdk_pool_handle,
+                                    sdk_wallet_steward,
                                     tdir,
                                     client_tdir,
                                     tconf,
                                     allPluginsPath,
                                     name='Epsilon')
-    sendReqsToNodesAndVerifySuffReplies(looper, stewardWallet, steward1, 5)
+    sdk_send_random_and_check(looper, txnPoolNodeSet,
+                              sdk_pool_handle, sdk_wallet_steward, 5)
     """
     check that pool and domain ledgers for new node are in synced state
     """
@@ -120,11 +118,12 @@ def test_6th_node_join_after_view_change_by_master_restart(
         timeout = waits.expectedPoolCatchupTime(nodeCount=len(pool_of_nodes))
         for node in pool_of_nodes:
             looper.run(eventually(catchuped, node, timeout=2 * timeout))
-    sendReqsToNodesAndVerifySuffReplies(looper, stewardWallet, steward1, 2)
+    sdk_send_random_and_check(looper, txnPoolNodeSet,
+                              sdk_pool_handle, sdk_wallet_steward, 2)
     new_psi_node = add_new_node(looper,
                                 pool_of_nodes,
-                                steward1,
-                                stewardWallet,
+                                sdk_pool_handle,
+                                sdk_wallet_steward,
                                 tdir,
                                 client_tdir,
                                 tconf,
