@@ -1,4 +1,4 @@
-from plenum.test.helper import sendReqsToNodesAndVerifySuffReplies
+from plenum.test.helper import sdk_send_random_and_check
 from plenum.test.node_catchup.helper import ensure_all_nodes_have_same_data
 from plenum.test.spy_helpers import get_count
 from plenum.test.test_node import ensureElectionsDone
@@ -19,11 +19,13 @@ def test_view_change_on_empty_ledger(txnPoolNodeSet, looper):
 
 # noinspection PyIncorrectDocstring
 def test_view_change_after_some_txns(looper, txnPoolNodeSet, viewNo,
-                                     wallet1, client1):
+                                     sdk_pool_handle,
+                                     sdk_wallet_client):
     """
     Check that view change is done after processing some of txns
     """
-    sendReqsToNodesAndVerifySuffReplies(looper, wallet1, client1, 4)
+    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
+                              sdk_wallet_client, 3)
 
     ensure_view_change(looper, txnPoolNodeSet)
     ensureElectionsDone(looper=looper, nodes=txnPoolNodeSet)
@@ -32,17 +34,19 @@ def test_view_change_after_some_txns(looper, txnPoolNodeSet, viewNo,
 
 # noinspection PyIncorrectDocstring
 def test_send_more_after_view_change(looper, txnPoolNodeSet,
-                                     wallet1, client1):
+                                     sdk_pool_handle, sdk_wallet_client):
     """
     Check that we can send more requests after view change
     """
-    sendReqsToNodesAndVerifySuffReplies(looper, wallet1, client1, 4)
+    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
+                              sdk_wallet_client, 4)
 
     ensure_view_change(looper, txnPoolNodeSet)
     ensureElectionsDone(looper=looper, nodes=txnPoolNodeSet)
     ensure_all_nodes_have_same_data(looper, nodes=txnPoolNodeSet)
 
-    sendReqsToNodesAndVerifySuffReplies(looper, wallet1, client1, 10)
+    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
+                              sdk_wallet_client, 10)
 
 
 def test_node_notified_about_primary_election_result(txnPoolNodeSet, looper):
