@@ -80,3 +80,11 @@ class KeyValueStorage(metaclass=ABCMeta):
 
     def __contains__(self, key):
         return self._has_key(key)
+
+    @staticmethod
+    def to_byte_repr(val):
+        if isinstance(val, int):
+            return str(val).encode()
+        if isinstance(val, str):
+            return str(val).encode()
+        return val
