@@ -32,51 +32,37 @@ class KeyValueStorageLeveldb(KeyValueStorage):
         return self._db_path
 
     def iterator(self, start=None, end=None, include_key=True, include_value=True, prefix=None):
-        if start and isinstance(start, int):
-            start = str(start)
-        if end and isinstance(end, int):
-            end = str(end)
-        if start and isinstance(start, str):
-            start = start.encode()
-        if end and isinstance(end, str):
-            end = end.encode()
+        start = self.to_byte_repr(start) if start is not None else None
+        end = self.to_byte_repr(end) if end is not None else None
 
         return self._db.RangeIter(key_from=start, key_to=end, include_value=include_value)
 
     def put(self, key, value):
-        if isinstance(key, str):
-            key = key.encode()
-        if isinstance(value, str):
-            value = value.encode()
+        key = self.to_byte_repr(key)
+        value = self.to_byte_repr(value)
         self._db.Put(key, value)
 
     def get(self, key):
-        if isinstance(key, str):
-            key = key.encode()
+        key = self.to_byte_repr(key)
         return self._db.Get(key)
 
     def remove(self, key):
-        if isinstance(key, str):
-            key = key.encode()
+        key = self.to_byte_repr(key)
         self._db.Delete(key)
 
     def setBatch(self, batch: Iterable[Tuple]):
         b = leveldb.WriteBatch()
         for key, value in batch:
-            if isinstance(key, str):
-                key = key.encode()
-            if isinstance(value, str):
-                value = value.encode()
+            key = self.to_byte_repr(key)
+            value = self.to_byte_repr(value)
             b.Put(key, value)
         self._db.Write(b, sync=False)
 
     def do_ops_in_batch(self, batch: Iterable[Tuple]):
         b = leveldb.WriteBatch()
         for op, key, value in batch:
-            if isinstance(key, str):
-                key = key.encode()
-            if isinstance(value, str):
-                value = value.encode()
+            key = self.to_byte_repr(key)
+            value = self.to_byte_repr(value)
             if op == self.WRITE_OP:
                 b.Put(key, value)
             elif op == self.REMOVE_OP:
