@@ -97,7 +97,8 @@ class Logger(metaclass=Singleton):
             interval=self._config.logRotationInterval,
             backupCount=self._config.logRotationBackupCount,
             utc=True,
-            maxBytes=self._config.logRotationMaxBytes)
+            maxBytes=self._config.logRotationMaxBytes,
+            compress=self._config.logRotationCompress)
         self._setHandler('file', new)
 
     def _setHandler(self, typ: str, new_handler):
