@@ -47,9 +47,16 @@ def looper(tdirAndLooper):
     return tdirAndLooper[1]
 
 
+BIG_NUM_OF_MSGS = 100000
+
+
 @pytest.fixture()
 def tconf():
-    return getConfig()
+    tmp = getConfig()
+    old_num = tmp.ZMQ_INTERNAL_QUEUE_SIZE
+    tmp.ZMQ_INTERNAL_QUEUE_SIZE = BIG_NUM_OF_MSGS
+    yield tmp
+    tmp.ZMQ_INTERNAL_QUEUE_SIZE = old_num
 
 
 @pytest.fixture(scope="module")
